%
%    Copyright (C) 2008  Colin Caprani - www.colincaprani.com
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

function nl = CNL(LM,L)
% Returns Consistent Nodal Loads from the load definitions
    [nloads,x] = size(LM);
    nl = zeros(4,1);

    for i = 1:nloads
        switch LM(i,2)
            case 1
                nl = nl + FEM_udl(LM(i,3), L);
            case 2
                nl = nl + FEM_pl(LM(i,3), LM(i,4),L);
            case 3
                nl = nl + FEM_pudl(LM(i,3), LM(i,4), LM(i,5), L);
            case 4
                nl = nl + FEM_ml(LM(i,3), LM(i,4), L);
        end
    end
    nl = nl(:);
end

function F = FEM_udl(w, L)
    % gives fixed end moments & shears for a fixed-fixed beam
    % Upwards reactions +, Anticlockwise moments +
    F = [w*L/2, w*L^2/12, w*L/2, -w*L^2/12];
    F = F';
end

function F = FEM_pl(p, a, L)
    % gives fixed end moments & shears for a fixed-fixed beam
    % Upwards reactions +, Anticlockwise moments +
    b = max(L-a,0);

    Ma = p*a*b^2/L^2;
    Mb = -p*a^2*b/L^2;
    Va = (p/L^3)*(b*L^2-a^2*b+a*b^2);
    Vb = (p/L^3)*(a*L^2+a^2*b-a*b^2);

    F = [Va, Ma, Vb, Mb];
    F = F';
end

function F = FEM_pudl(w, a, c, L)
    b = c+a;
    s = a + c/2; t = L-s;

    Ma = (w*c/L^2)*(s*t^2+(s-2*t)*c^2/12);
    Mb = -(w*c/L^2)*(t*s^2+(t-2*s)*c^2/12);
    Va = (L-b + c/2)*c*w/L;
    Vb = w*c - Va;

    F = [Va, Ma, Vb, Mb];
    F = F';
end

function F = FEM_ml(m, a, L)
    b = L-a;

    Ma = (m*b/L^2)*(2*a-b);
    Mb = (m*a/L^2)*(2*b-a);;
    Va = (m/L^2)*(4*a*b+L^2-a^2-b^2);
    Vb = -Va;

    F = [Va, Ma, Vb, Mb];
    F = F';
end