%
%    Copyright (C) 2008  Colin Caprani - www.colincaprani.com
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

function [x M V d] = mbr_values(f,disps,LM,L,E,I)
% Returns the moments, shears, rotations and deflections caused by all
% loading on a single member using superposition

[nloads,x] = size(LM);
nl = zeros(4,1);
npts = 100;
  
[x M V R d] = MaMb(f(2),f(4),L,E,I,npts);   % end moments

for i = 1:nloads
    switch LM(i,2)
        case 0
            Mt = zeros(npts+3,1); Vt = zeros(npts+3,1);
            Rt = zeros(npts+3,1); dt = zeros(npts+3,1);
        case 1
            w = LM(i,3);
            [x Mt Vt Rt dt] = udl(w,L,E,I,npts);
        case 2
            P = LM(i,3); a = LM(i,4);
            [x Mt Vt Rt dt] = pl(P,a,L,E,I,npts);
        case 3
            w = LM(i,3); a = LM(i,4); c = LM(i,5);
            [x Mt Vt Rt dt] = pudl(w,a,c,L,E,I,npts);
        case 4
            m = LM(i,3); a = LM(i,4);
            [x Mt Vt Rt dt] = ml(m,a,L,E,I,npts);
    end
    M = M+Mt; V = V+Vt; R = R+Rt; d = d+dt;
end

d = d + disps(1).*((2/L^3).*x.^3 - (3/L^2).*x.^2 +1);   % end displacements
d = d + disps(3).*((-2/L^3).*x.^3 + (3/L^2).*x.^2);
