%
%    Copyright (C) 2008  Colin Caprani - www.colincaprani.com
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

function [x M V R d] = pl(P, a, L, E, I, npts)
% Returns moments, shears, rotations and deflections at npts for a point
% load at point a
    x = [0,0:L/npts:L,L];
    b = max(L-a,0);

    Va = P*b/L;
    Ra = P*b*(b^2-L^2)/(6*L);

    V = Va - P.*Heaviside(x-a);
    M = Va.*x - P.*MB(x-a);
    R = (Va/2).*x.^2 - (P/2).*MB(x-a).^2 + Ra;
    d = (Va/6).*x.^3 - (P/6).*MB(x-a).^3 + Ra.*x;

    R = R./(E*I); d = d./(E*I);
    V(1) = 0; V(npts+3) = 0; V = V(:);
    M(1) = 0; M(npts+3) = 0; M = M(:);
    R = R(:); d = d(:); x = x(:);
end 

function y = MB(x)
% Macaulay Bracket
    y = max(x,0);
end

function y = Heaviside(x)
    y = zeros(size(x));
    y(x >= 0) = 1;
end