%
%    Copyright (C) 2008  Colin Caprani - www.colincaprani.com
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

function [x M V R d] = pudl(w, a, c, L, E, I, npts)
% Returns moments, shears, rotations and deflections at npts for a partial
% udl which runs from point a to point c
    x = [0,0:L/npts:L,L];

    b = c+a;
    Va = (L-b + c/2)*c*w/L;
    
    yL = (Va/6)*L^3 + (w/24)*(L-b)^4 - (w/24)*(L-a)^4;
    Ra = -yL/L;

    V = Va           - w*MB(x-a)          + w.*MB(x-b);
    M = Va.*x        - (w/2).*MB(x-a).^2  + (w/2).*MB(x-b).^2;
    R = (Va/2).*x.^2 - (w/6).*MB(x-a).^3  + (w/6).*MB(x-b).^3  + Ra;
    d = (Va/6).*x.^3 - (w/24).*MB(x-a).^4 + (w/24).*MB(x-b).^4 + Ra.*x;

    R = R./(E*I); d = d./(E*I);
    V(1) = 0; V(npts+3) = 0; V = V(:);
    M(1) = 0; M(npts+3) = 0; M = M(:);
    R = R(:); d = d(:); x = x(:);
end

function y = MB(x)
% Macaulay Bracket
    y = max(x,0);
end